@@ -30,7 +30,7 @@ import networkx as nx
 __author__ = 'Federico Ficarelli'
 __copyright__ = 'Copyright (c) 2015 Federico Ficarelli'
 __license__ = 'Apache License Version 2.0'
-__version__ = '1.2.1'
+__version__ = '1.3.1'
 
 VERSION = __version__
 # bumpversion can only search for {current_version}
@@ -95,6 +95,30 @@ def unique_everseen(iterable, key=None):  # pragma: no cover
                 yield element
 
 
+class _EventProxy(object):  # pylint: disable=too-few-public-methods
+    """ Proxy class to access :class:`~automaton.Event`
+    attributes.
+
+    Forwards every attribute access to the underlying proxied
+    :class:`~automaton.Event`.
+
+    .. important:
+        Unlike :class:`~automaton.Event`, instances of this type
+        are callables that trigger event transition in the proxied
+        :class:`~automaton.Automaton` instance.
+    """
+
+    def __init__(self, event, automaton):
+        self.__event = event
+        self.__automaton = automaton
+
+    def __getattr__(self, name):
+        return getattr(self.__event, name)
+
+    def __call__(self):
+        return self.__automaton.event(self.name)
+
+
 class Event(EventBase):
     """ Class that represents a state transition.
 
@@ -121,9 +145,9 @@ class Event(EventBase):
     @property
     def name(self):
         """ The actual user-defined name of the event as an
-        :class:`~automaton.automaton.Automaton` class member.
+        :class:`~automaton.Automaton` class member.
         If None, the Event isn't bounded to any specific
-        :class:`~automaton.automaton.Automaton` subclass. """
+        :class:`~automaton.Automaton` subclass. """
         return self._event_name
 
     def edges(self, data=False):
@@ -155,8 +179,8 @@ class Event(EventBase):
             components.append((dict(event=self.name), ))
         yield from product(*components)
 
-    def bind(self, name):
-        """ Binds the :class:`~automaton.automaton.Event` instance
+    def _bind(self, name):
+        """ Binds the :class:`~automaton.Event` instance
         to a particular event name.
 
         .. warning::
@@ -172,7 +196,7 @@ class Event(EventBase):
 
     def __get__(self, instance, owner):
         """ Enables the descriptor semantics on
-        :class:`~automaton.automaton.Event` instances. """
+        :class:`~automaton.Event` instances. """
         if instance is None:
             return self
         else:
@@ -180,12 +204,12 @@ class Event(EventBase):
                 # pylint: disable=attribute-defined-outside-init
                 self.__bound_instances = WeakKeyDictionary()
             if instance not in self.__bound_instances:
-                self.__bound_instances[instance] = lambda: instance.event(self._event_name)
+                self.__bound_instances[instance] = _EventProxy(event=self, automaton=instance)
             return self.__bound_instances[instance]
 
     def __set__(self, instance, value):
         """ Enables the descriptor semantics on
-        :class:`~automaton.automaton.Event` instances.
+        :class:`~automaton.Event` instances.
 
         Raises
         ------
@@ -199,7 +223,7 @@ class AutomatonMeta(type):
     """ The metaclass that must be applied on the ``automaton``-enabled classes'
     hierarchy.
 
-    The :meth:`~automaton.automaton.AutomatonMeta.__new__` method builds the
+    The :meth:`~automaton.AutomatonMeta.__new__` method builds the
     actual finite-state machine based on the user-provided events definition.
 
     Raises
@@ -216,7 +240,7 @@ class AutomatonMeta(type):
             value = getattr(cls, attr)
             if isinstance(value, Event):
                 # Important: bind event to its name as a class member
-                value.bind(attr)
+                value._bind(attr)  # pylint: disable=protected-access
                 # Collect states
                 states.update(value[0])  # Iterable of sources states, let's update the set
                 states.add(value[1])
@@ -270,13 +294,24 @@ class Automaton(metaclass=AutomatonMeta):
     initial_state : any, optional
         The initial state for this automaton instance. Defaults to None.
         Note that if automaton type has no default initial state
-        (specified via :attr:`~automaton.automaton.__default_initial_state__`),
+        (specified via :attr:`~automaton.__default_initial_state__`),
         this argument must be specified.
+    initial_event : any, optional
+        The initial event to be fired to deduce the initial state.
+        Defaults to `None`. Please note that `initial_state` and
+        and `initial_event` arguments *are mutually exclusive*,
+        specifying both of them will raise a `TypeError`.
+
+        .. note::
+            Since the *destination state* of an event is a *single state*
+            and due to the fact that events are class attributes
+            (so each event name is unique), *deducing the initial state
+            through a initial event is a well defined operation*.
 
     accepting_states : iterable, optional
         The accepting states for this automaton instance. Defaults to None.
         Note that if automaton type has default accepting states
-        (specified via :attr:`~automaton.automaton.__default_accepting_states__`),
+        (specified via :attr:`~automaton.__default_accepting_states__`),
         this argument takes precedence over that.
 
     Raises
@@ -285,6 +320,9 @@ class Automaton(metaclass=AutomatonMeta):
         The automaton type has no default initial state while no
         custom initial state specified during construction *or* the
         specified initial state is unknown.
+    TypeError
+        Both `initial_state` and `initial_event` arguments have been
+        specified while they are mutually exclusive.
     """
 
     __default_initial_state__ = None
@@ -293,7 +331,16 @@ class Automaton(metaclass=AutomatonMeta):
     __default_accepting_states__ = None
     """iterable: The default accepting states for the automaton type."""
 
-    def __init__(self, initial_state=None, accepting_states=None):
+    def __init__(self, initial_state=None, initial_event=None, accepting_states=None):
+        #
+        # 0. Initial event setup
+        #
+        if initial_event:
+            if initial_state:
+                raise TypeError("'initial_state' and 'initial_event' parameters can't be specified together")
+            if initial_event not in self.__events__:  # pylint: disable=no-member
+                raise InvalidTransitionError("Unrecognized event '{}'.".format(initial_event))
+            initial_state = getattr(self, initial_event).dest_state
         #
         # 1. Initial state setup
         #
@@ -371,7 +418,7 @@ class Automaton(metaclass=AutomatonMeta):
     @classmethod
     def _get_cut(cls, *states, inbound=True):
         """ Retrieves all the events that form a cut for the
-        all the specified subgraphs.
+        specified subgraphs.
 
         Parameters
         ----------
@@ -492,9 +539,9 @@ def __automaton_format__(automaton, fmt):
 
     Parameters
     ----------
-    automaton : `~automaton.Automaton` (instance or subclass)
+    automaton : :class:`~automaton.Automaton`
         The automaton to be formatted. It can be both an
-        instance and a class.
+        instance or a class.
     fmt : str
         The format specifier.
 
@@ -518,7 +565,7 @@ def get_table(automaton, traversal=None):
 
     Parameters
     ----------
-    automaton : `~automaton.Automaton`
+    automaton : :class:`~automaton.Automaton`
         The automaton to be rendered. It can be both
         a class and an instance.
     traversal : callable(graph), optional
@@ -533,7 +580,7 @@ def get_table(automaton, traversal=None):
 
     Yields
     ------
-    (source, dest, event)
+    tuple(source, dest, event)
         Yields one row at a time as a tuple containing
         the source and destination node of the edge and
         the name of the event associated with the edge.
@@ -560,6 +607,8 @@ def stategraph(automaton, fmt=None, traversal=None):  # pylint: disable=unused-a
         ...     stop = Event('yellow', 'red')
         >>> print( plantuml(TrafficLight) )  # doctest: +SKIP
 
+    ::
+
         @startuml
             green --> yellow : slowdown
             yellow --> red : stop
@@ -568,10 +617,10 @@ def stategraph(automaton, fmt=None, traversal=None):  # pylint: disable=unused-a
 
     Parameters
     ----------
-    automaton : `~automaton.Automaton`
+    automaton : :class:`~automaton.Automaton`
         The automaton to be rendered. It can be both
         a class and an instance.
-    fmt str, optional
+    fmt : str, optional
         Specifies the output format for the graph.
         Currently, the only supported format is
         `PlantUML <http://plantuml.com/state-diagram>`_.
@@ -622,6 +671,8 @@ def transitiontable(automaton, header=None, fmt=None, traversal=None):
         ...     stop = Event('yellow', 'red')
         >>> tabulate(TrafficLight) # doctest: +SKIP
 
+    ::
+
         ========  ======  ========
         Source    Dest    Event
         ========  ======  ========
@@ -632,7 +683,7 @@ def transitiontable(automaton, header=None, fmt=None, traversal=None):
 
     Parameters
     ----------
-    automaton : `~automaton.Automaton`
+    automaton : :class:`~automaton.Automaton`
         The automaton to be rendered. It can be both
         a class and an instance.
     header : list[str, str, str]
